@@ -67,6 +67,23 @@ static size_t getOCLCpp11AtomicMaxNumOps(StringRef Name) {
       .Default(0);
 }
 
+static Type *getBlockStructType(Value *Parameter) {
+  // In principle, this information should be passed to us from Clang via
+  // an elementtype attribute. However, said attribute requires that the
+  // function call be an intrinsic, which it is not. Instead, we rely on being
+  // able to trace this to the declaration of a variable: OpenCL C specification
+  // section 6.12.5 should guarantee that we can do this.
+  Value *UnderlyingObject = Parameter->stripPointerCasts();
+  Type *ParamType = nullptr;
+  if (auto *GV = dyn_cast<GlobalValue>(UnderlyingObject))
+    ParamType = GV->getValueType();
+  else if (auto *Alloca = dyn_cast<AllocaInst>(UnderlyingObject))
+    ParamType = Alloca->getAllocatedType();
+  else
+    llvm_unreachable("Blocks in OpenCL C must be traceable to allocation site");
+  return ParamType;
+}
+
 /// Return one of the SPIR-V 1.4 SignExtend or ZeroExtend image operands
 /// for a demangled function name, or 0 if the function does not return an
 /// integer type (e.g. read_imagef).
@@ -159,8 +176,12 @@ bool OCLToSPIRVBase::runOCLToSPIRV(Module &Module) {
 
   visit(*M);
 
-  for (Instruction *I : ValuesToDelete)
-    I->eraseFromParent();
+  for (auto &I : ValuesToDelete)
+    if (auto Inst = dyn_cast<Instruction>(I))
+      Inst->eraseFromParent();
+  for (auto &I : ValuesToDelete)
+    if (auto GV = dyn_cast<GlobalValue>(I))
+      GV->eraseFromParent();
 
   eraseUselessFunctions(M); // remove unused functions declarations
   LLVM_DEBUG(dbgs() << "After OCLToSPIRV:\n" << *M);
@@ -490,8 +511,7 @@ CallInst *OCLToSPIRVBase::visitCallAtomicCmpXchg(CallInst *CI) {
         }
         Expected = Args[1]; // temporary save second argument.
         Args[1] = new LoadInst(RetTy, Args[1], "exp", false, CI);
-        assert(Args[0]->getType()->getPointerElementType()->isIntegerTy() &&
-               Args[1]->getType()->isIntegerTy() &&
+        assert(Args[1]->getType()->isIntegerTy() &&
                Args[2]->getType()->isIntegerTy() &&
                "In SPIR-V 1.0 arguments of OpAtomicCompareExchange must be "
                "an integer type scalars");
@@ -1022,7 +1042,8 @@ void OCLToSPIRVBase::visitCallReadImageWithSampler(CallInst *CI,
         Value *SampledImgArgs[] = {Args[0], Args[1]};
         auto SampledImg = addCallInstSPIRV(
             M, getSPIRVFuncName(OpSampledImage), SampledImgTy, SampledImgArgs,
-            nullptr, CI, kSPIRVName::TempSampledImage);
+            nullptr, {ArgStructTys[0], ArgStructTys[1]}, CI,
+            kSPIRVName::TempSampledImage);
 
         Args[0] = SampledImg;
         Args.erase(Args.begin() + 1, Args.begin() + 2);
@@ -1145,6 +1166,7 @@ bool OCLToSPIRVBase::eraseUselessConvert(CallInst *CI, StringRef MangledName,
                     << *CI->getArgOperand(0) << '\n');
     CI->replaceAllUsesWith(CI->getArgOperand(0));
     ValuesToDelete.insert(CI);
+    ValuesToDelete.insert(CI->getCalledFunction());
     return true;
   }
   return false;
@@ -1537,9 +1559,7 @@ void OCLToSPIRVBase::visitCallEnqueueKernel(CallInst *CI,
   // Param Size: Size of block literal structure
   // Param Aligment: Aligment of block literal structure
   // TODO: these numbers should be obtained from block literal structure
-  Type *ParamType = getUnderlyingObject(BlockLiteral)->getType();
-  if (PointerType *PT = dyn_cast<PointerType>(ParamType))
-    ParamType = PT->getPointerElementType();
+  Type *ParamType = getBlockStructType(BlockLiteral);
   Args.push_back(getInt32(M, DL.getTypeStoreSize(ParamType)));
   Args.push_back(getInt32(M, DL.getPrefTypeAlignment(ParamType)));
 
@@ -1589,10 +1609,7 @@ void OCLToSPIRVBase::visitCallKernelQuery(CallInst *CI,
       M, CI,
       [=](CallInst *CI, std::vector<Value *> &Args) {
         Value *Param = *Args.rbegin();
-        Type *ParamType = getUnderlyingObject(Param)->getType();
-        if (PointerType *PT = dyn_cast<PointerType>(ParamType)) {
-          ParamType = PT->getPointerElementType();
-        }
+        Type *ParamType = getBlockStructType(Param);
         // Last arg corresponds to SPIRV Param operand.
         // Insert Invoke in front of Param.
         // Add Param Size and Param Align at the end.
@@ -1768,13 +1785,16 @@ void OCLToSPIRVBase::visitSubgroupAVCWrapperBuiltinCall(
       getSubgroupAVCIntelTyKind(CI->getCalledFunction()->getName());
   std::string MCETName =
       std::string(kOCLSubgroupsAVCIntel::TypePrefix) + "mce_" + TyKind + "_t";
-  auto *MCETy =
-      PointerType::get(getSubgroupAVCIntelMCEType(M, MCETName), SPIRAS_Private);
+  auto *MCESTy = getSubgroupAVCIntelMCEType(M, MCETName);
+  auto *MCETy = PointerType::get(MCESTy, SPIRAS_Private);
   std::string ToMCEFName = Prefix + OpKind + "_convert_to_mce_" + TyKind;
   Op ToMCEOC = OpNop;
   OCLSPIRVSubgroupAVCIntelBuiltinMap::find(ToMCEFName, &ToMCEOC);
   assert(ToMCEOC != OpNop && "Invalid Subgroup AVC Intel built-in call");
 
+  SmallVector<StructType *, 2> ParamTys;
+  getParameterTypes(CI, ParamTys);
+
   if (std::strcmp(TyKind, "payload") == 0) {
     // Wrapper built-ins which take the 'payload_t' argument return it as
     // the result: two conversion calls required.
@@ -1789,16 +1809,16 @@ void OCLToSPIRVBase::visitSubgroupAVCWrapperBuiltinCall(
         [=](CallInst *, std::vector<Value *> &Args, Type *&Ret) {
           Ret = MCETy;
           // Create conversion function call for the last operand
-          Args[Args.size() - 1] =
-              addCallInstSPIRV(M, getSPIRVFuncName(ToMCEOC), MCETy,
-                               Args[Args.size() - 1], nullptr, CI, "");
+          Args[Args.size() - 1] = addCallInstSPIRV(
+              M, getSPIRVFuncName(ToMCEOC), MCETy, Args[Args.size() - 1],
+              nullptr, {ParamTys[Args.size() - 1]}, CI, "");
 
           return getSPIRVFuncName(WrappedOC);
         },
         [=](CallInst *NewCI) -> Instruction * {
           // Create conversion function call for the return result
           return addCallInstSPIRV(M, getSPIRVFuncName(FromMCEOC), CI->getType(),
-                                  NewCI, nullptr, CI, "");
+                                  NewCI, nullptr, {MCESTy}, CI, "");
         },
         &Attrs);
   } else {
@@ -1809,9 +1829,9 @@ void OCLToSPIRVBase::visitSubgroupAVCWrapperBuiltinCall(
         [=](CallInst *, std::vector<Value *> &Args) {
           // Create conversion function call for the last
           // operand
-          Args[Args.size() - 1] =
-              addCallInstSPIRV(M, getSPIRVFuncName(ToMCEOC), MCETy,
-                               Args[Args.size() - 1], nullptr, CI, "");
+          Args[Args.size() - 1] = addCallInstSPIRV(
+              M, getSPIRVFuncName(ToMCEOC), MCETy, Args[Args.size() - 1],
+              nullptr, {ParamTys[Args.size() - 1]}, CI, "");
 
           return getSPIRVFuncName(WrappedOC);
         },
@@ -1849,6 +1869,7 @@ void OCLToSPIRVBase::visitSubgroupAVCBuiltinCallWithSampler(
                "Invalid Subgroup AVC Intel built-in call");
         auto SamplerIt = Args.begin() + (TyIt - ParamTys.begin());
         auto *SamplerVal = *SamplerIt;
+        auto *SamplerTy = *TyIt;
         Args.erase(SamplerIt);
         ParamTys.erase(TyIt);
 
@@ -1868,7 +1889,8 @@ void OCLToSPIRVBase::visitSubgroupAVCBuiltinCallWithSampler(
 
           Value *SampledImgArgs[] = {Args[I], SamplerVal};
           Args[I] = addCallInstSPIRV(M, getSPIRVFuncName(OpVmeImageINTEL),
-                                     SampledImgTy, SampledImgArgs, nullptr, CI,
+                                     SampledImgTy, SampledImgArgs, nullptr,
+                                     {ParamTys[I], SamplerTy}, CI,
                                      kSPIRVName::TempSampledImage);
         }
         return getSPIRVFuncName(OC);
