@@ -1160,9 +1160,11 @@ public:
     } else if (NameRef.startswith("vstore")) {
       addUnsignedArg(1);
     } else if (NameRef.startswith("ndrange_")) {
-      addUnsignedArg(-1);
+      addUnsignedArgs(0, 2);
       if (NameRef[8] == '2' || NameRef[8] == '3') {
-        setArgAttr(-1, SPIR::ATTR_CONST);
+        setArgAttr(0, SPIR::ATTR_CONST);
+        setArgAttr(1, SPIR::ATTR_CONST);
+        setArgAttr(2, SPIR::ATTR_CONST);
       }
     } else if (NameRef.contains("umax")) {
       addUnsignedArg(-1);
@@ -1269,22 +1271,18 @@ public:
       else
         addUnsignedArg(1);
     } else if (NameRef.startswith("intel_sub_group_block_write")) {
-      // distinguish write to image and other data types as position
-      // of uint argument is different though name is the same.
-      auto *Arg0Ty = getArgTy(0);
-      if (Arg0Ty->isPointerTy() &&
-          Arg0Ty->getPointerElementType()->isIntegerTy()) {
+      // distinguish write to image and other data types based on number of
+      // arguments--images have one more argument.
+      if (F->getFunctionType()->getNumParams() == 2) {
         addUnsignedArg(0);
         addUnsignedArg(1);
       } else {
         addUnsignedArg(2);
       }
     } else if (NameRef.startswith("intel_sub_group_block_read")) {
-      // distinguish read from image and other data types as position
-      // of uint argument is different though name is the same.
-      auto *Arg0Ty = getArgTy(0);
-      if (Arg0Ty->isPointerTy() &&
-          Arg0Ty->getPointerElementType()->isIntegerTy()) {
+      // distinguish read from image and other data types based on number of
+      // arguments--images have one more argument.
+      if (F->getFunctionType()->getNumParams() == 1) {
         setArgAttr(0, SPIR::ATTR_CONST);
         addUnsignedArg(0);
       }
@@ -1612,7 +1610,9 @@ Value *SPIRV::transSPIRVMemorySemanticsIntoOCLMemFenceFlags(
 
 void llvm::mangleOpenClBuiltin(const std::string &UniqName,
                                ArrayRef<Type *> ArgTypes,
+                               ArrayRef<PointerIndirectPair> PointerElementTys,
                                std::string &MangledName) {
   OCLUtil::OCLBuiltinFuncMangleInfo BtnInfo(ArgTypes);
+  BtnInfo.fillPointerElementTypes(PointerElementTys);
   MangledName = SPIRV::mangleBuiltin(UniqName, ArgTypes, &BtnInfo);
 }
