@@ -86,7 +86,7 @@ SPIRVToLLVMDbgTran::getDIFile(const std::string &FileName,
     // relations with other debug metadata is not going through DICompileUnit
     if (!Split.BaseName.empty()) {
       if (Source.hasValue()) {
-        StringRef SourceRef = StringRef(Source.getValue());
+        const StringRef SourceRef = StringRef(Source.getValue());
         return BuilderMap.begin()->second->createFile(
             Split.BaseName, Split.Path, CS, SourceRef);
       }
@@ -150,7 +150,7 @@ SPIRVToLLVMDbgTran::getStringSourceContinued(const SPIRVId Id,
   std::string Str = BM->get<SPIRVString>(Id)->getStr();
   using namespace SPIRVDebug::Operand::SourceContinued;
   for (auto *I : DebugInst->getContinuedInstructions()) {
-    std::string TmpStr =
+    const std::string TmpStr =
         BM->get<SPIRVString>(I->getArguments()[TextIdx])->getStr();
     Str.append(TmpStr);
   }
@@ -317,7 +317,7 @@ DIType *SPIRVToLLVMDbgTran::transTypePointer(const SPIRVExtInst *DebugInst) {
   DIType *PointeeTy = nullptr;
   if (BM->getEntry(Ops[BaseTypeIdx])->getOpCode() != OpTypeVoid)
     PointeeTy = transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
-  Optional<unsigned> AS;
+  llvm::Optional<unsigned> AS;
   SPIRVWord SC = getConstantValueOrLiteral(Ops, StorageClassIdx,
                                            DebugInst->getExtSetKind());
   if (SC != ~0U) // all ones denote no address space
@@ -427,8 +427,11 @@ SPIRVToLLVMDbgTran::transTypeArrayNonSemantic(const SPIRVExtInst *DebugInst) {
   if (DebugInst->getExtOp() == SPIRVDebug::TypeArray) {
     for (size_t I = SubrangesIdx; I < Ops.size(); ++I) {
       auto *SR = transDebugInst<DISubrange>(BM->get<SPIRVExtInst>(Ops[I]));
-      if (auto *Count = SR->getCount().get<ConstantInt *>())
-        TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
+      // LLVM 15 - exclusive workaround, get from a pointer union seem to be
+      // bugged
+      if (isa<ConstantInt *>(SR->getCount()))
+        if (auto *Count = SR->getCount().get<ConstantInt *>())
+          TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
       Subscripts.push_back(SR);
     }
   }
@@ -450,8 +453,11 @@ SPIRVToLLVMDbgTran::transTypeArrayDynamic(const SPIRVExtInst *DebugInst) {
   SmallVector<llvm::Metadata *, 8> Subscripts;
   for (size_t I = SubrangesIdx; I < Ops.size(); ++I) {
     auto *SR = transDebugInst<DISubrange>(BM->get<SPIRVExtInst>(Ops[I]));
-    if (auto *Count = SR->getCount().get<ConstantInt *>())
-      TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
+    // LLVM 15 - exclusive workaround, get from a pointer union seem to be
+    // bugged
+    if (isa<ConstantInt *>(SR->getCount()))
+      if (auto *Count = SR->getCount().get<ConstantInt *>())
+        TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
     Subscripts.push_back(SR);
   }
   DINodeArray SubscriptArray =
@@ -497,7 +503,7 @@ SPIRVToLLVMDbgTran::transTypeVector(const SPIRVExtInst *DebugInst) {
   // Clang rounds up the memory size of vectors to a power of 2.
   // Vulkan allows vec3 to have a memory size of 12, but in RenderDoc memory
   // size is not derived from debug info.
-  uint64_t Size = getDerivedSizeInBits(BaseTy) * bitCeil(Count);
+  const uint64_t Size = getDerivedSizeInBits(BaseTy) * bitCeil(Count);
 
   SmallVector<llvm::Metadata *, 8> Subscripts;
   Subscripts.push_back(getDIBuilder(DebugInst).getOrCreateSubrange(0, Count));
@@ -736,13 +742,14 @@ SPIRVToLLVMDbgTran::transTypeMemberNonSemantic(const SPIRVExtInst *DebugInst,
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
 
   DIFile *File = getFile(Ops[SourceIdx]);
-  SPIRVWord LineNo =
+  const SPIRVWord LineNo =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
-  StringRef Name = getString(Ops[NameIdx]);
-  DIType *BaseType = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
-  uint64_t OffsetInBits =
+  const StringRef Name = getString(Ops[NameIdx]);
+  DIType *BaseType =
+      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  const uint64_t OffsetInBits =
       BM->get<SPIRVConstant>(Ops[OffsetIdx])->getZExtIntValue();
-  SPIRVWord SPIRVFlags =
+  const SPIRVWord SPIRVFlags =
       getConstantValueOrLiteral(Ops, FlagsIdx, DebugInst->getExtSetKind());
   DINode::DIFlags Flags = DINode::FlagZero;
   if ((SPIRVDebug::FlagAccess & SPIRVFlags) == SPIRVDebug::FlagIsPublic) {
@@ -765,8 +772,8 @@ SPIRVToLLVMDbgTran::transTypeMemberNonSemantic(const SPIRVExtInst *DebugInst,
     return getDIBuilder(DebugInst).createStaticMemberType(
         Scope, Name, File, LineNo, BaseType, Flags, cast<llvm::Constant>(Val));
   }
-  uint64_t Size = BM->get<SPIRVConstant>(Ops[SizeIdx])->getZExtIntValue();
-  uint64_t Alignment = 0;
+  const uint64_t Size = BM->get<SPIRVConstant>(Ops[SizeIdx])->getZExtIntValue();
+  const uint64_t Alignment = 0;
 
   return getDIBuilder(ParentInst)
       .createMemberType(Scope, Name, File, LineNo, Size, Alignment,
@@ -976,11 +983,11 @@ DINode *SPIRVToLLVMDbgTran::transFunction(const SPIRVExtInst *DebugInst,
         Ops.size() > TargetFunctionNameIdx) {
       TargetFunction = getString(Ops[TargetFunctionNameIdx]);
     }
-    DIS = getDIBuilder(DebugInst).createFunction(Scope, Name, LinkageName, File,
-                                                 LineNo, Ty, ScopeLine, Flags,
-                                                 SPFlags, TParamsArray, FD,
-                                                 /*ThrownTypes*/ nullptr,
-                                                 /*Annotations*/ nullptr);
+    DIS = getDIBuilder(DebugInst).createFunction(
+        Scope, Name, LinkageName, File, LineNo, Ty, ScopeLine, Flags, SPFlags,
+        TParamsArray, FD,
+        /*ThrownTypes*/ nullptr,
+        /*Annotations*/ nullptr, TargetFunction);
   }
   DebugInstCache[DebugInst] = DIS;
 
@@ -1343,13 +1350,13 @@ DINode *SPIRVToLLVMDbgTran::transImportedEntry(const SPIRVExtInst *DebugInst) {
   assert(Ops.size() == (OpenCL::OperandCount - OffsetIdx) &&
          "Invalid number of operands");
   DIScope *Scope = getScope(BM->getEntry(Ops[OpenCL::ParentIdx - OffsetIdx]));
-  SPIRVWord Line = getConstantValueOrLiteral(Ops, OpenCL::LineIdx - OffsetIdx,
-                                             DebugInst->getExtSetKind());
+  const SPIRVWord Line = getConstantValueOrLiteral(
+      Ops, OpenCL::LineIdx - OffsetIdx, DebugInst->getExtSetKind());
   DIFile *File = getFile(Ops[OpenCL::SourceIdx - OffsetIdx]);
   auto *Entity = transDebugInst<DINode>(
       BM->get<SPIRVExtInst>(Ops[OpenCL::EntityIdx - OffsetIdx]));
-  SPIRVWord Tag = getConstantValueOrLiteral(Ops, OpenCL::TagIdx,
-                                            DebugInst->getExtSetKind());
+  const SPIRVWord Tag = getConstantValueOrLiteral(Ops, OpenCL::TagIdx,
+                                                  DebugInst->getExtSetKind());
   if (Tag == SPIRVDebug::ImportedModule) {
     if (!Entity)
       return getDIBuilder(DebugInst).createImportedModule(
@@ -1365,7 +1372,7 @@ DINode *SPIRVToLLVMDbgTran::transImportedEntry(const SPIRVExtInst *DebugInst) {
                                                           Line);
   }
   if (Tag == SPIRVDebug::ImportedDeclaration) {
-    StringRef Name = getString(Ops[OpenCL::NameIdx]);
+    const StringRef Name = getString(Ops[OpenCL::NameIdx]);
     if (DIGlobalVariableExpression *GVE =
             dyn_cast<DIGlobalVariableExpression>(Entity))
       return getDIBuilder(DebugInst).createImportedDeclaration(
@@ -1381,21 +1388,15 @@ DINode *SPIRVToLLVMDbgTran::transModule(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= OperandCount && "Invalid number of operands");
   DIScope *Scope = getScope(BM->getEntry(Ops[ParentIdx]));
-  // In case we translate DebugModuleINTEL instruction (not DebugModule of
-  // NonSemantic.Shader.200 spec), we should not apply the rule "literals are
-  // not allowed for NonSemantic specification". This is a hack to avoid getting
-  // constant value instead of literal in such case.
-  const SPIRVExtInstSetKind ExtKind =
-      DebugInst->getExtOp() == SPIRVDebug::Instruction::ModuleINTEL
-          ? SPIRVEIS_OpenCL_DebugInfo_100
-          : DebugInst->getExtSetKind();
-  SPIRVWord Line = getConstantValueOrLiteral(Ops, LineIdx, ExtKind);
+  SPIRVWord Line =
+      getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
   DIFile *File = getFile(Ops[SourceIdx]);
   StringRef Name = getString(Ops[NameIdx]);
   StringRef ConfigMacros = getString(Ops[ConfigMacrosIdx]);
   StringRef IncludePath = getString(Ops[IncludePathIdx]);
   StringRef ApiNotes = getString(Ops[ApiNotesIdx]);
-  bool IsDecl = getConstantValueOrLiteral(Ops, IsDeclIdx, ExtKind);
+  bool IsDecl =
+      getConstantValueOrLiteral(Ops, IsDeclIdx, DebugInst->getExtSetKind());
   return getDIBuilder(DebugInst).createModule(
       Scope, Name, ConfigMacros, IncludePath, ApiNotes, File, Line, IsDecl);
 }
@@ -1592,12 +1593,8 @@ SPIRVToLLVMDbgTran::transDebugIntrinsic(const SPIRVExtInst *DebugInst,
     DIExpression *Expr = GetExpression(Ops[ExpressionIdx]);
     auto *DbgValIntr = getDIBuilder(DebugInst).insertDbgValueIntrinsic(
         Val, LocalVar.first, Expr, LocalVar.second, BB);
-
-    std::vector<ValueAsMetadata *> MDs;
-    for (size_t I = 0; I != Expr->getNumLocationOperands(); ++I) {
-      MDs.emplace_back(ValueAsMetadata::get(Val));
-    }
-    if (!MDs.empty()) {
+    if (Expr->getNumLocationOperands() == 1) {
+      SmallVector<ValueAsMetadata *, 1> MDs = {ValueAsMetadata::get(Val)};
       DIArgList *AL = DIArgList::get(M->getContext(), MDs);
       cast<DbgVariableIntrinsic>(DbgValIntr)->setRawLocation(AL);
     }
@@ -1617,7 +1614,7 @@ DebugLoc SPIRVToLLVMDbgTran::transDebugScope(const SPIRVInstruction *Inst) {
   // If DebugLine and OpLine are both active give DebugLine priority
   if (auto DL = Inst->getDebugLine()) {
     using namespace SPIRVDebug::Operand::DebugLine;
-    SPIRVWordVec DebugLineArgs = DL->getArguments();
+    const SPIRVWordVec DebugLineArgs = DL->getArguments();
     Line =
         getConstantValueOrLiteral(DebugLineArgs, StartIdx, DL->getExtSetKind());
     Col = getConstantValueOrLiteral(DebugLineArgs, ColumnStartIdx,
@@ -1665,9 +1662,9 @@ MDNode *SPIRVToLLVMDbgTran::transDebugInlinedNonSemanticShader200(
   using namespace SPIRVDebug::Operand::InlinedAt::NonSemantic;
   SPIRVWordVec Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
-  SPIRVWord Line =
+  const SPIRVWord Line =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
-  unsigned Col =
+  const unsigned Col =
       getConstantValueOrLiteral(Ops, ColumnIdx, DebugInst->getExtSetKind());
   DILocalScope *Scope =
       cast<DILocalScope>(getScope(BM->getEntry(Ops[ScopeIdx])));
@@ -1697,7 +1694,7 @@ DIFile *SPIRVToLLVMDbgTran::getFile(const SPIRVId SourceId) {
     return getDIFile(getString(SourceArgs[FileIdx]));
 
   if (!isNonSemanticDebugInfo(Source->getExtSetKind())) {
-    std::string ChecksumStr =
+    const std::string ChecksumStr =
         getDbgInst<SPIRVDebug::DebugInfoNone>(SourceArgs[TextIdx])
             ? ""
             : getString(SourceArgs[TextIdx]);
@@ -1713,12 +1710,12 @@ DIFile *SPIRVToLLVMDbgTran::getFile(const SPIRVId SourceId) {
       // go together
       if (!getDbgInst<SPIRVDebug::DebugInfoNone>(SourceArgs[ChecksumKind]) &&
           !getDbgInst<SPIRVDebug::DebugInfoNone>(SourceArgs[ChecksumValue])) {
-        llvm::DIFile::ChecksumKind Kind = SPIRV::DbgChecksumKindMap::rmap(
+        const llvm::DIFile::ChecksumKind Kind = SPIRV::DbgChecksumKindMap::rmap(
             static_cast<SPIRVDebug::FileChecksumKind>(
                 BM->get<SPIRVConstant>(SourceArgs[ChecksumKind])
                     ->getZExtIntValue()));
-        StringRef Checksum = getString(SourceArgs[ChecksumValue]);
-        size_t ChecksumEndPos = Checksum.find_if_not(llvm::isHexDigit);
+        const StringRef Checksum = getString(SourceArgs[ChecksumValue]);
+        const size_t ChecksumEndPos = Checksum.find_if_not(llvm::isHexDigit);
         CS.emplace(Kind, Checksum.substr(0, ChecksumEndPos));
       }
     }
