@@ -696,9 +696,9 @@ public:
 
   llvm::Optional<ExtensionID> getRequiredExtension() const override {
     switch (static_cast<unsigned>(ExecMode)) {
-    case internal::ExecutionModeMaximumRegistersINTEL:
-    case internal::ExecutionModeMaximumRegistersIdINTEL:
-    case internal::ExecutionModeNamedMaximumRegistersINTEL:
+    case ExecutionModeMaximumRegistersINTEL:
+    case ExecutionModeMaximumRegistersIdINTEL:
+    case ExecutionModeNamedMaximumRegistersINTEL:
       return ExtensionID::SPV_INTEL_maximum_registers;
     default:
       return {};
@@ -767,9 +767,9 @@ public:
              IsOtherFP(EMK);
     };
     auto IsMaxRegisters = [&](auto EMK) {
-      return EMK == internal::ExecutionModeMaximumRegistersINTEL ||
-             EMK == internal::ExecutionModeMaximumRegistersIdINTEL ||
-             EMK == internal::ExecutionModeNamedMaximumRegistersINTEL;
+      return EMK == ExecutionModeMaximumRegistersINTEL ||
+             EMK == ExecutionModeMaximumRegistersIdINTEL ||
+             EMK == ExecutionModeNamedMaximumRegistersINTEL;
     };
     auto IsCompatible = [&](SPIRVExecutionMode *EM0, SPIRVExecutionMode *EM1) {
       if (EM0->getTargetId() != EM1->getTargetId())
@@ -904,8 +904,6 @@ public:
     case CapabilityVectorComputeINTEL:
     case CapabilityVectorAnyINTEL:
       return ExtensionID::SPV_INTEL_vector_compute;
-    case internal::CapabilityBFloat16ArithmeticINTEL:
-      return ExtensionID::SPV_INTEL_bfloat16_arithmetic;
     default:
       return {};
     }
