@@ -563,12 +563,14 @@ _SPIRV_OP(ConstantCompositeContinuedINTEL, 6091)
 _SPIRV_OP(SpecConstantCompositeContinuedINTEL, 6092)
 _SPIRV_OP(ControlBarrierArriveINTEL, 6142)
 _SPIRV_OP(ControlBarrierWaitINTEL, 6143)
+_SPIRV_OP(ArithmeticFenceEXT, 6145)
 _SPIRV_OP(Subgroup2DBlockLoadINTEL, 6231)
 _SPIRV_OP(Subgroup2DBlockLoadTransformINTEL, 6232)
 _SPIRV_OP(Subgroup2DBlockLoadTransposeINTEL, 6233)
 _SPIRV_OP(Subgroup2DBlockPrefetchINTEL, 6234)
 _SPIRV_OP(Subgroup2DBlockStoreINTEL, 6235)
 _SPIRV_OP(SubgroupMatrixMultiplyAccumulateINTEL, 6237)
+_SPIRV_OP(BitwiseFunctionINTEL, 6242)
 _SPIRV_OP(GroupIMulKHR, 6401)
 _SPIRV_OP(GroupFMulKHR, 6402)
 _SPIRV_OP(GroupBitwiseAndKHR, 6403)
